Rename the columns of a marker table to their canonical names, using the
aliases in .MARKER_ALIASES (matched case-insensitively).
Rename the columns of a marker table to their canonical names, using the
aliases in .MARKER_ALIASES (matched case-insensitively).