Ensure marker genes are in the scale.data layer of an assay of the Seurat object
Source:R/scrna-macros.R
EnsureSeuratScaleData.RdEnsure marker genes are in the scale.data layer of an assay of the Seurat object
R/scrna-macros.R
EnsureSeuratScaleData.RdEnsure marker genes are in the scale.data layer of an assay of the Seurat object