Run contaminant RNA correction on a Seurat object
Source:R/scrna-macros.R
RunSeuratContamCorrection.RdRun contaminant RNA correction on a Seurat object
Arguments
- object
Seurat object
- method
Method to use for contaminant RNA correction. Supported methods: "decontx" (using decontX function from the celda package) and "sccdc" (using scCDC package).
- decontXArgs
Arguments to pass to decontX functionn from the celda package. See
?celda::decontXfor details.- scCDCArgs
Arguments to pass to scCDC function from the scCDC package. It is a list with 3 elements: Detection, Quantification and Correction, which are lists of arguments to pass to the corresponding functions from the scCDC package:
scCDC::ContaminationDetection,scCDC::ContaminationQuantificationandscCDC::ContaminationCorrection.