Canonicalize the marker table columns and select a subset of them
Source:R/scrna-markers.R
apply_marker_cols.RdCanonicalize the marker table columns and select a subset of them
R/scrna-markers.R
apply_marker_cols.RdCanonicalize the marker table columns and select a subset of them